@@ -10,72 +10,76 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/2022Q2/bin',
- 'BINLIBDEST': '/2022Q2/lib/python3.9',
+ 'BINDIR': '/usr/pkg/bin',
+ 'BINLIBDEST': '/usr/pkg/lib/python3.9',
  'BLDLIBRARY': '-L. -lpython3.9',
- 'BLDSHARED': 'cc -pthread -shared -L. -Wl,-zrelro -L/2022Q2/lib '
-              '-Wl,-R/2022Q2/lib -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib',
+ 'BLDSHARED': 'cc -shared -L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
+              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 '
+              '-Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'x86_64-chromeos-linux-gnu',
+ 'BUILD_GNU_TYPE': 'x86_64-unknown-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 'cc -pthread',
+ 'CC': 'cc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -D_FORTIFY_SOURCE=2 '
-           '-I/usr/include -I/2022Q2/include -I/2022Q2/include/ncurses '
-           '-I/2022Q2/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-           '-I/2022Q2/include -I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
-           '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-           '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
+           '-I/usr/include -I/usr/pkg/include -I/usr/pkg/include/ncurses '
+           '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+           '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
+           '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+           '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
+           '-I/usr/pkg/include/db4',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-                     '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
+ 'CONFIGURE_CFLAGS': '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
+                     '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
+                     '-I/usr/pkg/include/db4',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/2022Q2/include '
-                       '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
- 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include '
+                       '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4',
+ 'CONFIGURE_LDFLAGS': '-Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
+                      '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/2022Q2' "
+ 'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr/pkg' "
                 "'--with-system-ffi' '--without-ensurepip' "
-                "'--without-pymalloc' '--prefix=/2022Q2' "
-                "'--build=x86_64-chromeos-linux' "
-                "'--host=x86_64-chromeos-linux' '--mandir=/2022Q2/man' "
-                "'--enable-option-checking=yes' "
-                "'build_alias=x86_64-chromeos-linux' "
-                "'host_alias=x86_64-chromeos-linux' 'CC=cc' 'CFLAGS=-O2 "
-                '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-                "-I/2022Q2/include/ncurses -I/2022Q2/include/db4' "
-                "'LDFLAGS=-Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib' 'LIBS=' "
-                "'CPPFLAGS=-I/usr/include -I/2022Q2/include "
-                "-I/2022Q2/include/ncurses -I/2022Q2/include/db4' "
-                "'PKG_CONFIG=/root/sda3/pkgsrc.2022Q2/lang/python39/work/.tools/bin/pkg-config' "
+                "'--without-pymalloc' '--prefix=/usr/pkg' "
+                "'--build=x86_64-unknown-linux' '--host=x86_64-unknown-linux' "
+                "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
+                "'build_alias=x86_64-unknown-linux' "
+                "'host_alias=x86_64-unknown-linux' 'CC=cc' 'CFLAGS=-O2 "
+                '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+                "-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4' "
+                "'LDFLAGS=-Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 "
+                "-L/usr/pkg/lib -Wl,-R/usr/pkg/lib' 'LIBS=' "
+                "'CPPFLAGS=-I/usr/include -I/usr/pkg/include "
+                "-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4' "
+                "'PKG_CONFIG=/usr/pkgsrc/lang/python39/work/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/root/sda3/pkgsrc.2022Q2/lang/python39/work/.buildlink/lib64/pkgconfig:/root/sda3/pkgsrc.2022Q2/lang/python39/work/.buildlink/lib/pkgconfig:/root/sda3/pkgsrc.2022Q2/lang/python39/work/.buildlink/share/pkgconfig'",
- 'CONFINCLUDEDIR': '/2022Q2/include',
- 'CONFINCLUDEPY': '/2022Q2/include/python3.9',
+                "'PKG_CONFIG_LIBDIR=/usr/pkgsrc/lang/python39/work/.buildlink/lib64/pkgconfig:/usr/pkgsrc/lang/python39/work/.buildlink/lib/pkgconfig:/usr/pkgsrc/lang/python39/work/.buildlink/share/pkgconfig'",
+ 'CONFINCLUDEDIR': '/usr/pkg/include',
+ 'CONFINCLUDEPY': '/usr/pkg/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13/coverage.info',
- 'COVERAGE_REPORT': '/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13/lcov-report',
+ 'COVERAGE_INFO': '/usr/pkgsrc/lang/python39/work/Python-3.9.14/coverage.info',
+ 'COVERAGE_REPORT': '/usr/pkgsrc/lang/python39/work/Python-3.9.14/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q2/include '
-             '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -I/usr/include '
-             '-I/2022Q2/include -I/2022Q2/include/ncurses '
-             '-I/2022Q2/include/db4',
- 'CXX': 'c++ -pthread',
- 'DESTDIRS': '/2022Q2 /2022Q2/lib /2022Q2/lib/python3.9 '
-             '/2022Q2/lib/python3.9/lib-dynload',
- 'DESTLIB': '/2022Q2/lib/python3.9',
+ 'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
+             '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -I/usr/include '
+             '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
+             '-I/usr/pkg/include/db4',
+ 'CXX': 'c++',
+ 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.9 '
+             '/usr/pkg/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/usr/pkg/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/2022Q2/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/usr/pkg/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -539,44 +543,46 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'x86_64-chromeos-linux-gnu',
- 'INCLDIRSTOMAKE': '/2022Q2/include /2022Q2/include /2022Q2/include/python3.9 '
-                   '/2022Q2/include/python3.9',
- 'INCLUDEDIR': '/2022Q2/include',
- 'INCLUDEPY': '/2022Q2/include/python3.9',
- 'INSTALL': '/bin/install -c -o root -g root',
- 'INSTALL_DATA': '/bin/install -c -o root -g root -m 644',
- 'INSTALL_PROGRAM': '/bin/install -c -s -o root -g root -m 755',
- 'INSTALL_SCRIPT': '/bin/install -c -o root -g root -m 755',
- 'INSTALL_SHARED': '/bin/install -c -o root -g root -m 755',
+ 'HOST_GNU_TYPE': 'x86_64-unknown-linux-gnu',
+ 'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
+                   '/usr/pkg/include/python3.9 /usr/pkg/include/python3.9',
+ 'INCLUDEDIR': '/usr/pkg/include',
+ 'INCLUDEPY': '/usr/pkg/include/python3.9',
+ 'INSTALL': '/usr/bin/install -c -o root -g root',
+ 'INSTALL_DATA': '/usr/bin/install -c -o root -g root -m 644',
+ 'INSTALL_PROGRAM': '/usr/bin/install -c -s -o root -g root -m 755',
+ 'INSTALL_SCRIPT': '/usr/bin/install -c -o root -g root -m 755',
+ 'INSTALL_SHARED': '/usr/bin/install -c -o root -g root -m 755',
  'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'c++ -pthread -shared',
- 'LDFLAGS': '-L. -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib -Wl,-zrelro '
-            '-L/2022Q2/lib -Wl,-R/2022Q2/lib',
+ 'LDCXXSHARED': 'c++ -shared',
+ 'LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib '
+            '-Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
+            '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'cc -pthread -shared -L. -Wl,-zrelro -L/2022Q2/lib '
-             '-Wl,-R/2022Q2/lib -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib',
+ 'LDSHARED': 'cc -shared -L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
+             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 '
+             '-Wl,-R/usr/lib64 -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
  'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/2022Q2/lib/python3.9',
- 'LIBDIR': '/2022Q2/lib',
- 'LIBFFI_INCLUDEDIR': '/2022Q2/include',
+ 'LIBDEST': '/usr/pkg/lib/python3.9',
+ 'LIBDIR': '/usr/pkg/lib',
+ 'LIBFFI_INCLUDEDIR': '/usr/pkg/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/2022Q2/lib/pkgconfig',
- 'LIBPL': '/2022Q2/lib/python3.9/config-3.9',
+ 'LIBPC': '/usr/pkg/lib/pkgconfig',
+ 'LIBPL': '/usr/pkg/lib/python3.9/config-3.9',
  'LIBPYTHON': '',
  'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -lintl -lpthread -ldl  -lutil -lm',
+ 'LIBS': '-lcrypt -lintl -ldl  -lm',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': 'cc -pthread',
+ 'LINKCC': 'cc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
@@ -587,13 +593,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/2022Q2/lib/python3.9',
+ 'MACHDESTLIB': '/usr/pkg/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'cc -pthread',
+ 'MAINCC': 'cc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/2022Q2/man',
+ 'MANDIR': '/usr/pkg/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
@@ -619,11 +625,11 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '-I/2022Q2/include',
- 'OPENSSL_LDFLAGS': '-L/2022Q2/lib',
+ 'OPENSSL_INCLUDES': '-I/usr/pkg/include',
+ 'OPENSSL_LDFLAGS': '-L/usr/pkg/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
+ 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -659,76 +665,82 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
                              '-D_FORTIFY_SOURCE=2 -I/usr/include '
-                             '-I/2022Q2/include -I/2022Q2/include/ncurses '
-                             '-I/2022Q2/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
-                             '-I/usr/include -I/2022Q2/include '
-                             '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
-                             '-O2 -D_FORTIFY_SOURCE=2 -I/usr/include '
-                             '-I/2022Q2/include -I/2022Q2/include/ncurses '
-                             '-I/2022Q2/include/db4 -std=gnu99 -Wextra '
+                             '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
+                             '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
+                             '-I/usr/include -I/usr/pkg/include '
+                             '-I/usr/pkg/include/ncurses '
+                             '-I/usr/pkg/include/db4 -O2 -D_FORTIFY_SOURCE=2 '
+                             '-I/usr/include -I/usr/pkg/include '
+                             '-I/usr/pkg/include/ncurses '
+                             '-I/usr/pkg/include/db4 -std=gnu99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include -I/2022Q2/include '
-                             '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
-                             '-I/usr/include -I/2022Q2/include '
-                             '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
-                             '-fPIC -DPy_BUILD_CORE_BUILTIN',
+                             '-I./Include -I/usr/include -I/usr/pkg/include '
+                             '-I/usr/pkg/include/ncurses '
+                             '-I/usr/pkg/include/db4 -I/usr/include '
+                             '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
+                             '-I/usr/pkg/include/db4 -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-              '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-              '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
-              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-              '-I/2022Q2/include/ncurses -I/2022Q2/include/db4',
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+              '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+              '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
+              '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+              '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-                   '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-                   '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
-                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-                   '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -std=gnu99 '
-                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
+                   '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
+                   '-std=gnu99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
-                   '-I/2022Q2/include -I/2022Q2/include/ncurses '
-                   '-I/2022Q2/include/db4 -I/usr/include -I/2022Q2/include '
-                   '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -fPIC '
+                   '-I/usr/pkg/include -I/usr/pkg/include/ncurses '
+                   '-I/usr/pkg/include/db4 -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib '
-                    '-Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib',
- 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/2022Q2/include '
-                '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
-                '-I/usr/include -I/2022Q2/include -I/2022Q2/include/ncurses '
-                '-I/2022Q2/include/db4',
+ 'PY_CORE_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
+                    '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -Wl,-zrelro '
+                    '-L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib '
+                    '-Wl,-R/usr/pkg/lib',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include '
+                '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
+                '-I/usr/include -I/usr/pkg/include -I/usr/pkg/include/ncurses '
+                '-I/usr/pkg/include/db4',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L. -Wl,-zrelro -L/2022Q2/lib -Wl,-R/2022Q2/lib -Wl,-zrelro '
-               '-L/2022Q2/lib -Wl,-R/2022Q2/lib',
+ 'PY_LDFLAGS': '-L. -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 -L/usr/pkg/lib '
+               '-Wl,-R/usr/pkg/lib -Wl,-zrelro -L/usr/lib64 -Wl,-R/usr/lib64 '
+               '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -O2 '
-                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/2022Q2/include '
-                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 -O2 '
+                        '-D_FORTIFY_SOURCE=2 -I/usr/include -I/usr/pkg/include '
+                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
                         '-std=gnu99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include -I/2022Q2/include '
-                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 '
-                        '-I/usr/include -I/2022Q2/include '
-                        '-I/2022Q2/include/ncurses -I/2022Q2/include/db4 -fPIC',
+                        '-I./Include -I/usr/include -I/usr/pkg/include '
+                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
+                        '-I/usr/include -I/usr/pkg/include '
+                        '-I/usr/pkg/include/ncurses -I/usr/pkg/include/db4 '
+                        '-fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -737,13 +749,13 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13',
- 'SCRIPTDIR': '/2022Q2/lib',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python39/work/Python-3.9.14',
+ 'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -lintl -lpthread -ldl  -lutil -lm',
+ 'SHLIBS': '-lcrypt -lintl -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 1,
+ 'SHM_NEEDS_LIBRT': 0,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -778,10 +790,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python39/work/Python-3.9.14 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/pkgsrc/lang/python39/work/Python-3.9.14 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -790,7 +802,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.9 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.9',
  'WINDOW_HAS_FLAGS': 1,
@@ -804,9 +816,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13',
- 'abs_srcdir': '/root/sda3/pkgsrc.2022Q2/lang/python39/work/Python-3.9.13',
- 'datarootdir': '/2022Q2/share',
- 'exec_prefix': '/2022Q2',
- 'prefix': '/2022Q2',
+ 'abs_builddir': '/usr/pkgsrc/lang/python39/work/Python-3.9.14',
+ 'abs_srcdir': '/usr/pkgsrc/lang/python39/work/Python-3.9.14',
+ 'datarootdir': '/usr/pkg/share',
+ 'exec_prefix': '/usr/pkg',
+ 'prefix': '/usr/pkg',
  'srcdir': '.'}
